@@ -1,5 +1,5 @@
 truncatedPbg <-
-function (p, trunc = 0.2) 
+function (p, trunc = 0.2)
     {
         stopifnot((trunc>0)&(trunc<=1))
         stopifnot(is.vector(p))
@@ -10,8 +10,8 @@ function (p, trunc = 0.2)
             1
         }
         else {
-            mix <- dbinom(1:L,L,trunc)
-            prob <- 1 - pgamma(-log(w/(trunc^(1:L))),1:L)
+            mix <- stats::dbinom(1:L,L,trunc)
+            prob <- 1 - stats::pgamma(-log(w/(trunc^(1:L))),1:L)
             sum(mix*prob)
         }
-    }
+}
